import React from 'react';

const AddAmenitiesPrice = ({
expectedPrice,
setExpectedPrice,
priceUnit,
setPriceUnit,
basicRequirements,
setBasicRequirements
}) => {
const priceUnits = [
 { value: 'total', label: 'Total Price' },
 { value: 'per-sq-ft', label: 'Per Square Feet' },
 { value: 'per-sq-yd', label: 'Per Square Yards' }
 ];

const handleBasicRequirementChange = (requirement) => {
  setBasicRequirements(requirement);
};

return (
<div className="px-4 py-6 sm:px-6 sm:py-8 lg:px-8">
<h2 className="text-xl font-bold sm:text-2xl">Add amenities & Price</h2>
<p className="mt-2 text-gray-600 text-sm sm:text-base">
 These are the features buyers look for. Highlighting them attracts more responses.
</p>
{/* Basic Requirements Section */}
<div className="mt-6">
<h3 className="text-lg font-medium">Basic Requirements</h3>
<div className="mt-4 flex flex-wrap gap-4 sm:space-x-6">
{['water', 'electricity', 'roadAccess', 'boundaryWall'].map((requirement) => (
<label
key={requirement}
className="flex items-center space-x-2 cursor-pointer"
>
<input
type="radio"
name="basicRequirements"
checked={basicRequirements === requirement}
onChange={() => handleBasicRequirementChange(requirement)}
className="h-4 w-4 text-purple-600 rounded focus:ring-purple-500"
/>
<span className="text-gray-700 capitalize text-sm sm:text-base">
{requirement}
</span>
</label>
 ))}
</div>
</div>
{/* Price and Price Unit */}
<div className="mt-6 grid gap-4 sm:mt-8 sm:grid-cols-2 sm:gap-6">
<div>
<label className="mb-2 block font-medium text-sm sm:text-base">
 Expected Price
</label>
<input
type="text"
placeholder="Enter expected price"
value={expectedPrice}
onChange={(e) => setExpectedPrice(e.target.value)}
className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
/>
</div>
<div>
<label className="mb-2 block font-medium text-sm sm:text-base">
 Price Unit
</label>
<select
value={priceUnit}
onChange={(e) => setPriceUnit(e.target.value)}
className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5 appearance-none"
>
<option value="">Select price unit</option>
{priceUnits.map(unit => (
<option key={unit.value} value={unit.value}>
{unit.label}
</option>
 ))}
</select>
</div>
</div>
</div>
 );
};
export default AddAmenitiesPrice;